<?php
namespace Teknisa\FIS\Controllers;

use \Teknisa\Libs\Service\CRUD;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Estado extends \Teknisa\FIS\Controllers\TeknisaCrud {

    public function __construct(CRUD $crudService, ParameterBag $parameterBag, Environment $environment, $ger01200estadoservice) {
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
        $this->parameterBag          = $parameterBag;
        $this->ger01200estadoservice = $ger01200estadoservice;
    }

    public function findWebService(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'ger01200_estado_websefaz';
        $this->parameterBagColumns = array('NRORG', 'CDPAIS', 'SGESTADO', 'IDAMBIENTE', 'IDSERVICO');
        parent::find($request,$response);
    }
    
    public function findWebServiceSvc(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'ger01200_estado_websefazsvc';
        $this->parameterBagColumns = array('NRORG', 'IDAMBIENTE');
        parent::find($request,$response);
    }
    
    public function findEditSvc (DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'ger01200_estado_websefaz_editSvc';
        $this->parameterBagColumns = array('NRORG', 'IDAMBIENTE', 'CDSVC');
        parent::find($request,$response);
    }
    
    public function saveEditSvc (DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'ger01200_estado_websefaz_editSvc';
        $row = $request->getDataSet()->getRows()[0];
        $this->parameterBagColumns = array('NRORG', 'IDAMBIENTE', 'CDSVC');
        parent::save($request,$response);
    }
    
    public function saveWebService (DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'ger01200_estado_websefaz';
        $row = $request->getDataSet()->getRows()[0];
        $campos = array();
        
        if ($row['IDSERVICO'] == 'NF') {
            $campos = array('WSRECEPCAO', 'WSRETRECEPCAO', 'WSEVENTO', 'WSCONSULTACAD', 'WSSTATUSSERVICO', 
                            'WSINUTILIZACAO', 'WSCONSULTAPRO', 'WSAUTORIZACAO', 'WSRETAUTORIZACAO', 'WSDOWNLOADNF', 'WSCONSULTADEST');
        } else if ($row['IDSERVICO'] == 'MDF') {
            $campos = array('WSRECEPCAOMDF', 'WSRETRECEPCAOMDF', 'WSEVENTOMDF', 'WSCONSULTAMDF', 'WSSTATUSSERVMDF', 'WSCONSMDFNAOENCE');
        } else if ($row['IDSERVICO'] == 'NFC') {
            $campos = array('WSAUTORIZACAONFC', 'WSRETAUTORIZACAONFC', 'WSINUTILIZACAONFC', 
                            'WSEVENTONFC', 'WSSTATUSSERVNFC', 'WSCONSULTANFC', 'WSLINKQRCODENFC');
        } else if ($row['IDSERVICO'] == 'CTE') {
            $campos = array ('WSRECEPCAOCTE', 'WSRETRECEPCAOCTE', 'WSEVENTOCTE', 'WSCONSULTACADCTE', 
                            'WSSTATUSSERVCTE', 'WSINUTILIZACTE', 'WSCONSULTAPROCTE');
        }
        
        foreach ($campos as $campo) {
            if(empty($row[$campo]))
                $row[$campo] = null;
        }
        
        $this->parameterBagColumns = array('NRORG', 'CDPAIS', 'SGESTADO', 'IDAMBIENTE', 'IDSERVICO');
        parent::save($request,$response);
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "estado";
            $nrorgLogada = $this->environment->getNrOrgTrab();
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria->addCondition('NRORG', 'IN', array($nrorgLogada, 0));
            $this->crudService->find($response, $filterCriteria);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
            $this->ger01200estadoservice->saveEstado($rows[0]);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}